%define major       5
%define majorminor  %{major}.2.5
%define lname       lzma
%define libname     %mklibname %{lname} %{major}
%define libdev      %mklibname -d %{lname}

# Extra documentation is installed by xz,
# these definitions are for where they exist/go
%define xz_pkgdocdir   %{_datadir}/doc/%{name}
%define dev_pkgdocdir  %{_datadir}/doc/%{libdev}

Summary:          XZ utils
Name:             xz
Version:          5.2.5
Release:          %mkrel 2
# Scripts xz{grep,diff,less,more} and symlinks (copied from gzip) are
# GPLv2+, binaries are Public Domain (linked against LGPL getopt_long but its
# OK), documentation is Public Domain.
License:          GPLv2+ and Public Domain
Group:            Archiving/Compression
Source0:          http://tukaani.org/xz/%{name}-%{version}.tar.xz
Source1:          xzme
Requires:         %{libname} = %{version}-%{release}
# add special tuning for text files, parameter: '--text':
Patch0:           xz-5.2.0-text-tune.patch
# Used to contain /usr/share/man/de/man1/xz.1.xz
Conflicts:        man-pages-de < 4.0.0-3

%rename           lzma
BuildRequires:    pkgconfig(zlib)
BuildRequires:    diffutils
URL:              http://tukaani.org/xz/

%description
XZ provides very high compression ratio and fast decompression. The
core of the XZ utils is Igor Pavlov's LZMA SDK containing the actual
LZMA encoder/decoder. LZMA utils add a few scripts which provide
gzip-like command line interface and a couple of other XZ related
tools. Also provides:

- Average compression ratio 30% better than that of gzip and 15%
  better than that of bzip2.

- Decompression speed is only little slower than that of gzip, being
  two to five times faster than bzip2.

- In fast mode, compresses faster than bzip2 with a comparable
  compression ratio.

- Achieving the best compression ratios takes four to even twelve
  times longer than with bzip2. However. this doesn't affect
  decompressing speed.

- Very similar command line interface than what gzip and bzip2 have.

%package -n       %{libname}
Summary:          Libraries for decoding XZ/LZMA compression
Group:            System/Libraries
Requires(pre):    filesystem >= 2.1.9-18
Conflicts:        %{name} < %{version}-%{release}

%description -n   %{libname}
Libraries for decoding LZMA compression.

%package -n       %{libdev}
Summary:          Devel libraries & headers for liblzma
Group:            Development/C
Requires(pre):    filesystem >= 2.1.9-18
Requires:         %{libname} = %{version}
Provides:         %{lname}-devel = %{version}-%{release}
Provides:         lib%{lname}-devel = %{version}-%{release}
Provides:         xz-devel

%description -n %{libdev}
Devel libraries & headers for liblzma.

%prep
%setup -q
%autopatch -p1

%build
CFLAGS="%{optflags} -O3 -funroll-loops" \
%configure
%make_build

%install
%make_install
install -m755 %{SOURCE1} -D %{buildroot}%{_bindir}/xzme

rm -f %{buildroot}%{_libdir}/*.la
%find_lang %{name} --with-man --all-name

# Move examples to devel subpackage
mkdir -p %{buildroot}%{dev_pkgdocdir}
mv %{buildroot}%{xz_pkgdocdir}/examples* %{buildroot}%{dev_pkgdocdir}

%check
%__make check

%files -f %{name}.lang
%doc %{xz_pkgdocdir}
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%doc COPYING
%{_libdir}/liblzma.so.%{majorminor}
%{_libdir}/liblzma.so.%{major}

%files -n %{libdev}
%doc COPYING
%doc %{dev_pkgdocdir}/examples*
%defattr(644,root,root,755)
%{_includedir}/%{lname}.h
%dir %{_includedir}/%{lname}
%{_includedir}/%{lname}/*.h
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/pkgconfig/lib%{lname}.pc


%changelog
* Tue Feb 02 2021 pterjan <pterjan> 5.2.5-2.mga8
+ Revision: 1674563
- Add missing Conflicts

* Thu Mar 19 2020 luigiwalser <luigiwalser> 5.2.5-1.mga8
+ Revision: 1557997
- 5.2.5
- remove upstream patches

* Sun Feb 16 2020 umeabot <umeabot> 5.2.4-5.mga8
+ Revision: 1532774
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Sep 17 2019 tmb <tmb> 5.2.4-4.mga8
+ Revision: 1443121
- liblzma: Avoid memcpy(NULL, foo, 0) because it is undefined behavior
- xz: Fix an integer overflow with 32-bit off_t

* Sun Sep 23 2018 umeabot <umeabot> 5.2.4-2.mga7
+ Revision: 1302005
- Mageia 7 Mass Rebuild

* Tue May 29 2018 kekepower <kekepower> 5.2.4-1.mga7
+ Revision: 1232993
- Update to version 5.2.4

* Wed Sep 06 2017 joequant <joequant> 5.2.3-2.mga7
+ Revision: 1151683
- rebuild with gcc7

* Fri Dec 30 2016 luigiwalser <luigiwalser> 5.2.3-1.mga6
+ Revision: 1078706
- 5.2.3

* Sun Apr 03 2016 tv <tv> 5.2.2-3.mga6
+ Revision: 997766
- provides xz-devel (compatibility with FC)

* Fri Feb 12 2016 umeabot <umeabot> 5.2.2-2.mga6
+ Revision: 959352
- Mageia 6 Mass Rebuild

* Mon Oct 05 2015 shlomif <shlomif> 5.2.2-1.mga6
+ Revision: 886442
- New version 5.2.2 - patch thanks to Neal Gompa (Son_Goku).

* Fri Aug 21 2015 tmb <tmb> 5.2.1-2.mga6
+ Revision: 867621
- rebuild for new gcc

* Mon Jun 22 2015 shlomif <shlomif> 5.2.1-1.mga6
+ Revision: 839198
- New version 5.2.1

* Mon Dec 22 2014 tmb <tmb> 5.2.0-1.mga5
+ Revision: 804939
- 5.2.0 stable

* Wed Oct 15 2014 umeabot <umeabot> 5.1.4-0.beta.4.mga5
+ Revision: 740872
- Second Mageia 5 Mass Rebuild

* Thu Oct 02 2014 tmb <tmb> 5.1.4-0.beta.3.mga5
+ Revision: 734915
- make the lib conflict older xz to ensure upgrade in same transaction

* Thu Oct 02 2014 tmb <tmb> 5.1.4-0.beta.2.mga5
+ Revision: 734894
- xz must have strict deps on lzma lib as does not have stable api

* Wed Oct 01 2014 luigiwalser <luigiwalser> 5.1.4-0.beta.1.mga5
+ Revision: 733831
- update to 5.1.4beta
- rediff patch 0

* Tue Sep 16 2014 umeabot <umeabot> 5.1.3-0.alpha.3.mga5
+ Revision: 690809
- Mageia 5 Mass Rebuild

* Tue Aug 19 2014 tv <tv> 5.1.3-0.alpha.2.mga5
+ Revision: 665729
- drop dietlibc build (no more needed by stage1)

* Fri Mar 14 2014 shlomif <shlomif> 5.1.3-0.alpha.1.mga5
+ Revision: 603484
- Upgrade to 5.1.3 (MGA #13018).

* Fri Oct 18 2013 umeabot <umeabot> 5.1.2-0.alpha.4.mga4
+ Revision: 520864
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 5.1.2-0.alpha.3.mga3
+ Revision: 387537
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 02 2012 tv <tv> 5.1.2-0.alpha.2.mga3
+ Revision: 302007
- restore lzma provides

* Tue Oct 02 2012 tv <tv> 5.1.2-0.alpha.1.mga3
+ Revision: 302002
- new release (like FC & mdv) (multithreaded compression)
- rediff patch 0
- drop very old provides/conflicts
- fix build with dietlibc
- explain patch 0

* Sat Jul 21 2012 colin <colin> 5.0.4-2.mga3
+ Revision: 273158
- Update for usrmove

* Mon Jun 25 2012 fwang <fwang> 5.0.4-1.mga3
+ Revision: 263355
- new version 5.0.4

* Sat Apr 28 2012 colin <colin> 5.0.3-3.mga2
+ Revision: 234087
- Move liblzma to / from /usr (needed by systemctl+kmod)

* Sun Jan 15 2012 tv <tv> 5.0.3-2.mga2
+ Revision: 196475
- build with dietlibc

* Sun Jul 17 2011 fwang <fwang> 5.0.3-1.mga2
+ Revision: 125415
- new version 5.0.3

* Fri Apr 08 2011 tmb <tmb> 5.0.2-1.mga1
+ Revision: 82058
- liblzma: Fix a memory leak in stream_encoder.c (P1)
- update to 5.0.2
- update url

* Sat Jan 08 2011 blino <blino> 5.0.0-2.mga1
+ Revision: 576
- imported package xz

